==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Feedback/language/lang-arabic.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","");
define("_YOURNAME","");
define("_MESSAGE","");
define("_YOUREMAIL"," ");
define("_FEEDBACKNOTE","All comments and suggestions about this web site are very welcome and a valuable source of information for us. Thanks!");
define("_FEEDBACKTITLE","Feedback Form");
define("_FEEDBACK","Feedback");
define("_FBENTERNAME","ERROR: Please enter your name!");
define("_FBENTEREMAIL","ERROR: Please enter your e-mail address!");
define("_FBENTERMESSAGE","ERROR: Please enter a message!");
define("_SENDEREMAIL","Sender's Email");
define("_SENDERNAME","Sender's Name");
define("_FBMAILSENT","Mail has been sent!");
define("_FBTHANKSFORCONTACT","Thank you for contacting us");

?>

==> phpnuke-6.0.tgz: www/phpnuke/html/modules/Feedback/language/lang-arabic.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","");
define("_YOURNAME","");
define("_MESSAGE","");
define("_YOUREMAIL"," ");
define("_FEEDBACKNOTE","     !");
define("_FEEDBACKTITLE"," ");
define("_FEEDBACK","");
define("_FBENTERNAME",":   !");
define("_FBENTEREMAIL",":    !");
define("_FBENTERMESSAGE",":   !");
define("_SENDEREMAIL"," ");
define("_SENDERNAME"," ");
define("_FBMAILSENT","  !");
define("_FBTHANKSFORCONTACT"," ");

?>
